# Jugement Majoritaire
[![Build Status](https://travis-ci.org/nim65s/django-jugemaj.svg?branch=master)](https://travis-ci.org/nim65s/django-jugemaj)
[![Coverage Status](https://coveralls.io/repos/github/nim65s/django-jugemaj/badge.svg?branch=master)](https://coveralls.io/github/nim65s/django-jugemaj?branch=master)


Application de vote par [Jugement Majoritaire](https://fr.wikipedia.org/wiki/Jugement_majoritaire).


## Requirements

- [ndh](https://pypi.python.org/pypi/ndh) (which requires [django](https://www.djangoproject.com/),
  [django-autoslug](https://github.com/justinmayer/django-autoslug/),
  [django-bootstrap4](https://github.com/zostera/django-bootstrap4) (can be made optional on request))

Tested with:
- Python 3.6, 3.7, 3.8
- [Django](https://www.djangoproject.com/) 2.0, 2.1, 2.2, 3.0

## Theory

- [A theory of measuring, electing, and ranking. *Michel Balinski and Rida Laraki*. In PNAS 2007](https://doi.org/10.1073/pnas.0702634104)
- [Majority Judgment vs Majority Rule, *Michel Balinski and Rida Laraki*](http://www.lamsade.dauphine.fr/sites/default/IMG/pdf/cahier_377.pdf)
